@@ -1,6 +1,6 @@
 package Hadoop::Streaming;
 BEGIN {
-  $Hadoop::Streaming::VERSION = '0.102490';
+  $Hadoop::Streaming::VERSION = '0.102520';
 }
 
 #ABSTRACT: Contains Mapper, Combiner and Reducer roles to simplify writing Hadoop Streaming jobs 
@@ -17,7 +17,7 @@ Hadoop::Streaming - Contains Mapper, Combiner and Reducer roles to simplify writ
 
 =head1 VERSION
 
-version 0.102490
+version 0.102520
 
 =head1 SYNOPSIS
 
@@ -26,23 +26,23 @@ version 0.102490
 
     sub map 
     { 
-        my ($line) = @_;
+        my ($self, $line) = @_;
         ...
-        emit( $key => $value);
+        $self->emit( $key => $value);
     }
     sub reduce 
     { 
-        my ( $key, $value_iterator) = @_;
+        my ( $self, $key, $value_iterator) = @_;
         ...
         while( $value_iterator->has_next() ) { ... }
-        emit( $key, $composite_value );
+        $self->emit( $key, $composite_value );
     } 
     sub combine 
     { 
-        my ( $key, $value_iterator) = @_;
+        my ( $self, $key, $value_iterator) = @_;
         ...
         while( $value_iterator->has_next() ) { ... }
-        emit( $key, $composite_value );
+        $self->emit( $key, $composite_value );
     }
 
     package My::Hadoop::Example::Mapper;
@@ -189,7 +189,9 @@ Run this in hadoop from the shell:
 
 $streaming_jar_name is the full path to the streaming jar provided by the installed hadoop.  For my 0.20 install the path is:
 
-The -D line is optional.  If included, -D lines must come directly after the jar name.
+  /usr/lib/hadoop-0.20/contrib/streaming/hadoop-0.20.1+152-streaming.jar
+
+The -D line is optional.  If included, -D lines must come directly after the jar name and before other options.
 
 For this hadoop job to work, the mapper, combiner and reducer must be full paths that are valid on each box in the hadoop cluster.  There are a few ways to make this work.
 
